complete -c decasify -s l -l locale -d 'The locale of the input text' -r -f -a "en\t''
tr\t''
es\t''"
complete -c decasify -s c -l case -d 'The desired output case' -r -f -a "lower\t''
sentence\t''
title\t''
upper\t''"
complete -c decasify -s s -l style -d 'Proffered style guide' -r -f -a "ap\t''
cmos\t''
gruber\t''
default\t''
tdk\t''
rae\t''
fundeu\t''"
complete -c decasify -s O -l overrides -d 'Override words' -r
complete -c decasify -s h -l help -d 'Print help (see more with \'--help\')'
